@@ -76,12 +76,12 @@ class ReferenceImageConnector:
                                                  headers=self._construct_headers())
         return [dict_to_dataclass(reference_image, ReferenceImage) for reference_image in answer["result"]]
 
-    async def get_reference_image_file_ids(self, stream_url: str, date: datetime) -> list[str]:
-        payload = {"stream_url": stream_url, "iso_date": date.isoformat()}
+    async def get_reference_image_file_ids(self, rtsp_urls: list[str], date: datetime) -> dict[str, list[str]]:
+        payload = {"rtsp_urls": rtsp_urls, "iso_date": date.isoformat()}
 
-        answer = await self._connector.get("/reference_image/get",
-                                           url_query=payload,
-                                           headers=self._construct_headers())
+        answer = await self._connector.post_json("/reference_image/get",
+                                                 payload=payload,
+                                                 headers=self._construct_headers())
         return answer["result"]
 
     async def add_reference_image(self,
